@@ -14,11 +14,11 @@ test_that("check condition_occurrence and cohort1 work", {
   # mock data
   cdm <- mockPatientProfiles(con = connection(), writeSchema = writeSchema())
   # check it works with cohort1 table in mockdb
-  expect_true(typeof(cdm$cohort1 %>% addFutureObservation() %>% dplyr::collect()) == "list")
-  expect_true("future_observation" %in% colnames(cdm$cohort1 %>% addFutureObservation()))
+  expect_true(typeof(cdm$cohort1 |> addFutureObservation() |> dplyr::collect()) == "list")
+  expect_true("future_observation" %in% colnames(cdm$cohort1 |> addFutureObservation()))
   # check it works with condition_occurrence table in mockdb
-  expect_true(typeof(cdm$condition_occurrence %>% addFutureObservation(indexDate = "condition_start_date") %>% dplyr::collect()) == "list")
-  expect_true("future_observation" %in% colnames(cdm$condition_occurrence %>% addFutureObservation(indexDate = "condition_start_date")))
+  expect_true(typeof(cdm$condition_occurrence |> addFutureObservation(indexDate = "condition_start_date") |> dplyr::collect()) == "list")
+  expect_true("future_observation" %in% colnames(cdm$condition_occurrence |> addFutureObservation(indexDate = "condition_start_date")))
 
   mockDisconnect(cdm = cdm)
 })
@@ -54,13 +54,13 @@ test_that("check working example with cohort1", {
     cohort2 = cohort1
   )
 
-  result <- cdm$cohort1 %>%
-    addFutureObservation() %>%
+  result <- cdm$cohort1 |>
+    addFutureObservation() |>
     dplyr::collect()
 
   expect_true(all(colnames(cohort1) %in% colnames(result)))
 
-  expect_true(all(result %>%
+  expect_true(all(result |>
     dplyr::select("future_observation") ==
     dplyr::tibble(
       future_observation =
@@ -115,12 +115,12 @@ test_that("check working example with condition_occurrence", {
     observation_period = obs1
   )
 
-  result <- cdm$condition_occurrence %>%
-    addFutureObservation(indexDate = "condition_start_date") %>%
+  result <- cdm$condition_occurrence |>
+    addFutureObservation(indexDate = "condition_start_date") |>
     dplyr::collect()
 
   expect_true(all(
-    result %>% dplyr::select("future_observation") ==
+    result |> dplyr::select("future_observation") ==
       dplyr::tibble(
         future_observation =
           c(
@@ -175,7 +175,7 @@ test_that("different name", {
     observation_period = obs1
   )
 
-  cdm$condition_occurrence <- cdm$condition_occurrence %>%
+  cdm$condition_occurrence <- cdm$condition_occurrence |>
     addFutureObservation(
       indexDate = "condition_start_date", futureObservationName = "fh"
     )
@@ -241,10 +241,10 @@ test_that("priorHistory and future_observation - outside of observation period",
     condition_occurrence = co
   )
 
-  cdm$cohort1a <- cdm$condition_occurrence %>%
+  cdm$cohort1a <- cdm$condition_occurrence |>
     addFutureObservation(indexDate = "condition_start_date")
   # both should be NA
-  expect_true(all(is.na(cdm$cohort1a %>% dplyr::pull(future_observation))))
+  expect_true(all(is.na(cdm$cohort1a |> dplyr::pull(future_observation))))
 
   mockDisconnect(cdm = cdm)
 })
@@ -289,23 +289,23 @@ test_that("multiple observation periods", {
     cohort1 = cohort1
   )
 
-  cdm$cohort1a <- cdm$cohort1 %>%
+  cdm$cohort1a <- cdm$cohort1 |>
     addFutureObservation(indexDate = "cohort_start_date")
 
-  expect_true(nrow(cdm$cohort1a %>% dplyr::collect()) == 2)
-  expect_true(all(cdm$cohort1a %>% dplyr::pull(future_observation) ==
+  expect_true(nrow(cdm$cohort1a |> dplyr::collect()) == 2)
+  expect_true(all(cdm$cohort1a |> dplyr::pull(future_observation) ==
     as.numeric(difftime(as.Date("2015-01-01"),
       as.Date("2012-02-01"),
       units = "days"
     ))))
 
   # from cohort end date
-  cdm$cohort1a <- cdm$cohort1 %>%
+  cdm$cohort1a <- cdm$cohort1 |>
     addFutureObservation(
       indexDate = "cohort_end_date",
       futureObservationName = "fh_from_c_end"
     )
-  expect_true(all(cdm$cohort1a %>% dplyr::pull("fh_from_c_end") ==
+  expect_true(all(cdm$cohort1a |> dplyr::pull("fh_from_c_end") ==
     as.numeric(difftime(as.Date("2015-01-01"),
       as.Date("2013-02-01"),
       units = "days"
